Americká společnost Reflection AI světu představila Beam, open-weight model s 501 miliardami parametrů (z toho 23 miliard aktivních), určený především pro programování a práci autonomních agentů. Podle autorů jejich model nabízí výkon srovnatelný s většími modely při výrazně nižších nárocích na výpočetní výkon. Beam nyní ještě prochází závěrečným testováním, na stránkách Reflection AI se však lze zaregistrovat a získat předběžný přístup. Váhy modelu, dokumentace a nástroje pro vývojáře mají být zveřejněny v průběhu tohoto měsíce.
OpenCourant je komunitní fork OpenRadioss, tj. open source softwaru pro simulace havárií, nárazů a vysoce nelineárních dynamických dějů metodou konečných prvků. Společnost Siemens v loňském roce dokončila akvizici společnosti Altair Engineering, jež před čtyřmi lety uvolnila open source verzi OpenRadioss svého proprietárního softwaru Radioss. Minulý týden Siemens OpenRadioss pohřbil. Integroval jej do svého softwaru Simcenter, webovou stránku OpenRadioss přesměroval na Simcenter a repozitář OpenRadioss na GitHubu odstranil.
Pořadatelé devátého ročníku komunitního setkání správců nejen českých a slovenských sítí – CSNOG 2027, které se uskuteční 20. a 21. ledna, vyhlásili Call for Abstracts. Náměty na vystoupení mohou zájemci přihlašovat do 31. října na webu akce a vybírat mohou ze tří sekcí – správa sítí, legislativa a regulace a akademické projekty. Zveřejněny byly také Call of Partners určené sponzorům a partnerům setkání, kteří by například chtěli mít na
… více »Strata je open-source inferenční engine, který umožňuje lokálně provozovat rozsáhlý čínský model Qwen3.8-Flash-Next, který by jinak nejspíše vyžadoval serverovou infrastrukturu, na běžném herním počítači s alespoň 12 GB VRAM, 32 GB RAM a dostatkem místa na SSD. Nároky na paměť a rychlost generování se liší s použitou variantou modelu Qwen. Zdrojový kód je dostupný na GitHubu, pod licencí MIT.
Americký prezident Donald Trump oznámil vznik federální Jednotky pro superinteligenci (Super Intelligence Force), která má koordinovat postup vlády, technologických firem, náboženských organizací a dalších institucí v oblasti rychle se rozvíjející umělé inteligence (Trumpem oficiálně nazývanou superinteligencí). SIF, podřízená přímo Trumpovi, má pomoci Spojeným státům udržet v oblasti SI technologický náskok nad světem a
… více »Klient je e-mailový klient pro GNOME s nativní podporou Proton Mailu, PGP a spamfiltrem řízeným AI. Napsaný je v Go s GTK4 a libadwaita. Připojuje se přímo k Proton Mailu (bez Proton Bridge), ke Gmailu, k Seznam.cz a k libovolné schránce IMAP/SMTP. Každou novou zprávu nejdřív posoudí spamfiltr a teprve potom ji ukáže a ohlásí. Rozhraní je česky a anglicky.
Hra Doom nově běží také v SQL databázi CedarDB. Představen byl SQLDoom. Vyzkoušet lze online demo. Zdrojové kódy jsou k dispozici na GitHubu.
Multiplatformní open source aplikace scrcpy (Wikipedie) pro zrcadlení připojeného zařízení se systémem Android na desktopu a umožňující ovládání tohoto zařízení z desktopu, byla vydána v nové verzi 5.0. S podporou hardwarového dekódování videa na desktopu.
Moderní linker mold, rychlejší alternativa k LLVM lld nebo wild, byl vydán v nové major verzi 3.0.0. Přepsán byl z C++ do Rustu.
Po osmi letech od vydání verze 2.0 byla vydána nová major verze 3.0 multiplatformního editoru tagů MusicBrainz Picard (Wikipedie). Přehled novinek, vylepšení a oprav v changelogu.
/home/user1/dir/dir/dir/dir/file /home/user2/dir/dir/file /home/user3/dir/dir/dir/dir/dir/file /etc/dir/dir/file /mnt/disk/dir/dir/dir/file ..... .....Chtěl bych ty soubory zazálohovat, ale netuším jak přinutit tar aby zachoval práva a vlastníka adresářů. Spouštím to jako
tar -czvf archiv.tgz -T filelist.txtU souborů v archivu jsou ty práva v pořádku, ale u adresářů tar nastaví jako vlastníka root:root a práva 0755. Prostě mi jde o to, jak z relativně rozsáhlého filesystému vyzobat soubory a ty zazálohovat i s cestou včetně práv nadřazených adresářů. Poradíte něco?
archive="/home/zaloha/$(cat /etc/hostname)_$(date '+%Y-%m-%d').tar.gz" dir=$(mktemp -d) rsync -a --files-from=/home/zaloha/files.txt / $dir cd $dir tar -czvf $archive . chmod 600 $archive cd .. rm -r $dirAle přijde mi to jako docela prasečina ty soubory někam dočasně kopírovat aby se zachovaly práva adresářů i po rozbalení. Nevíte o nějakém čistějším řešení? Možná nějak cpio a rourou přímo do taru? ...zkusím ješte poexperimentovat.
tar --one-top-level -xzf $archiveVyvoří to podadresář.
cpio -ov < filelist.txt > archiv.cpioRozbaliť:
cpio -idv < archiv.cpio'o' je 'output to archive'
Ak cesty k súborom obsahujú medzeru/tab/... tak jednotlivé mená súborov by mali byť oddelené nulovym bajtom a nie EOL a cpio potom treba pridať flag '0'
Skombinovať sa to dá pekne s find ... -print resp. find ... -print0.
A prípadne sa dá pri rozbaľovaní pridať ešte
'm' - zachovať file modification timecpio -ov < filelist.txt | gzip > archiv.cpio.gza rozbalit
zcat archiv.cpio.gz | cpio -idvpřípadně se dá použít přepínač
--no-absolute-filenames aby se to nerozbalilo na původní místo ale do aktuálního adresáře. Doporučuju ale mít v tom seznamu souborů taky všecky adresáře a podadresáře v cestě k souboru. Jinak se nemusí zachovat jejich původní práva.
find Thunderbird | cpio -vo | gzip > Thunderbird.cpio.gznebo
cd Thunderbird; find | cpio -vo | gzip > ../Thunderbird.cpio.gzNěkteré verze taru prý neumí číst soubory ze seznamu tam se cpio hodí použít, ale na obyčejné rekurzivní balení všeho je tar lepší.
-p, --preserve-permissions extract information about file permissions (default for superuser)
Dělám to jako root, tak ten přepínač nemá nanic vliv vůbec.Nepomohlo by přidat --same-owner (viz zde)?
#!/bin/bash
# mapfile číta po riadkoch, tak nebude problém s medzerami v názvoch súborov
# Ak ale súbory majú v názve "\n", chcelo by to iný prístup
mapfile -t < list
# Vyrobíme si ten zoznam adresárov
for F in "${MAPFILE[@]}" ; do dirname "$F" ; done | sort -u >list-with-dirs
# Pridáme zoznam súborov
cat list >>list-with-dirs
# --no-recursion zabezpečí, že sa v archíve budú iba požadované súbory a adresáre bez obsahu
sudo tar -czf archive.tgz -C source --no-recursion -T list-with-dirs
mkdir -p /tmp/a/b/c/d/e/f
touch /tmp/a/b/c/d/e/f/file
find /tmp/a -type f > /tmp/list
mapfile -t < /tmp/list
for F in "${MAPFILE[@]}" ; do dirname "$F" ; done | sort -u
to vypíše jenom ten poslední adresář
/tmp/a/b/c/d/e/fAby to fungovalo tak by ten výstup měl vypadat nějak takto:
/tmp /tmp/a /tmp/a/b /tmp/a/b/c /tmp/a/b/c/d /tmp/a/b/c/d/e /tmp/a/b/c/d/e/f
filelist=/tmp/filelist.txt
dirlist=/tmp/dirlist.txt
IFS="\n"
t=$(mktemp)
cat $filelist |
while read f; do
cd "$(dirname $f)"
until [ "$(pwd)" = "/" ]; do
pwd >> $t
cd ..
done
done
sort -u < $t > $dirlist
cat $dirlist $filelist > /tmp/list.txt
rm $t $dirlist
tar -czvf archive.tgz --no-recursion -T /tmp/list.txt
Toto mi jakžtakž funguje, ale myslím že použitelné to bude maximálně do pár desítek/stovek souborů protože ta rychlost je tragická. Tak teď nevím co je menší zlo. Jestli toto nebo ten rsync :-/
cd a pwd. Hlavný problém je ale v tom, že sa každý adresár vyhodnocuje stále dokola znova a znova. Toto by mohlo pomôcť:
declare -A processed
mapfile -t < list
for F in "${MAPFILE[@]}" ; do
F="$(dirname "$F")"
while [ "$F" != "." -a "$F" != "/" ] ; do
test -z "${processed[$F]:+_}" || break
echo "$F"
processed[$F]=1
F="$(dirname "$F")"
done
done | sort >list-with-dirs
cat list >>list-with-dirs
sudo tar -czf archive.tgz -C source --no-recursion -T list-with-dirs
P.S.: sort -u by už nemal byť potrebný, možno ani sort.
Tiskni
Sdílej: